[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Build](https://github.com/theislab/ehrapy/workflows/Build%20ehrapy%20Package/badge.svg)](https://github.com/theislab/ehrapy/actions?workflow=Package)
[![Codecov](https://codecov.io/gh/theislab/ehrapy/branch/master/graph/badge.svg)](https://codecov.io/gh/theislab/ehrapy)
[![License](https://img.shields.io/github/license/theislab/ehrapy)](https://opensource.org/licenses/Apache2.0)
[![PyPI](https://img.shields.io/pypi/v/ehrapy.svg)](https://pypi.org/project/ehrapy/)
[![Python Version](https://img.shields.io/pypi/pyversions/ehrapy)](https://pypi.org/project/ehrapy)
[![Read the Docs](https://img.shields.io/readthedocs/ehrapy/latest.svg?label=Read%20the%20Docs)](https://ehrapy.readthedocs.io/)
[![Test](https://github.com/theislab/ehrapy/workflows/Run%20ehrapy%20Tests/badge.svg)](https://github.com/theislab/ehrapy/actions?workflow=Tests)
[![PyPI](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)

<img src="https://user-images.githubusercontent.com/21954664/156930990-0d668468-0cd9-496e-995a-96d2c2407cf5.png" alt="ehrapy logo">

# ehrapy overview

<img src="https://user-images.githubusercontent.com/99650244/217562449-e05ab1dd-9c04-44fc-a042-b993dd9d4eea.png" alt="ehrapy overview">

## Features

-   Exploratory and targeted analysis of Electronic Health Records
-   Quality control & preprocessing
-   Visualization & Exploration
-   Clustering & trajectory inference

## Installation

You can install _ehrapy_ via [pip] from [PyPI]:

```console
$ pip install ehrapy
```

## Usage

Please have a look at the [Usage documentation][usage] and the [tutorials][tutorials].

```python
import ehrapy as ep
```

## Credits

This package was created with [cookietemple] using [cookiecutter] based on [hypermodern_python_cookiecutter].

[cookiecutter]: https://github.com/audreyr/cookiecutter
[cookietemple]: https://cookietemple.com
[hypermodern_python_cookiecutter]: https://github.com/cjolowicz/cookiecutter-hypermodern-python
[pip]: https://pip.pypa.io/
[pypi]: https://pypi.org/
[usage]: https://ehrapy.readthedocs.io/en/latest/usage/usage.html
[tutorials]: https://ehrapy.readthedocs.io/en/latest/tutorials/index.html
